@@ -27,6 +27,7 @@ import copy
 from omero.rtypes import rstring, rlist, unwrap, wrap
 from django.conf import settings
 from copy import deepcopy
+from past.builtins import long
 
 from omeroweb.webclient.tree import build_clause
 from omeroweb.webclient.tree import parse_permissions_css
@@ -41,8 +42,8 @@ logger = logging.getLogger(__name__)
 
 def _escape_chars_like(query):
     escape_chars = {
-        "%": "\%",
-        "_": "\_",
+        "%": r"\%",
+        "_": r"\_",
     }
 
     for k, v in escape_chars.items():
@@ -88,12 +89,12 @@ def _set_parameters(mapann_ns=[], mapann_names=[],
     where_clause = []
 
     if mapann_names is not None and len(mapann_names) > 0:
-        manlist = [rstring(unicode(n)) for n in mapann_names]
+        manlist = [rstring(n) for n in mapann_names]
         params.add('filter', rlist(manlist))
         where_clause.append("mv.name in (:filter)")
 
     if mapann_ns is not None and len(mapann_ns) > 0:
-        mnslist = [rstring(unicode(n)) for n in mapann_ns]
+        mnslist = [rstring(n) for n in mapann_ns]
         params.add("ns", rlist(mnslist))
         where_clause.append("a.ns in (:ns)")
 
@@ -359,7 +360,7 @@ def marshal_screens(conn, mapann_value, query=False,
     service_opts.setOmeroGroup(group_id)
 
     # TODO: Joining wellsample should be enough since wells are annotated
-    # with the same annotaitons as images. In the future if that change,
+    # with the same annotations as images. In the future if that changes,
     # query has to be restored to:
     # -     count(distinct i.id) as imgCount)
     # - from ImageAnnotationLink ial join ial.child a join a.mapValue mv
@@ -637,7 +638,7 @@ def marshal_plates(conn, screen_id,
     qs = conn.getQueryService()
 
     # TODO: Joining wellsample should be enough since wells are annotated
-    # with the same annotaitons as images. In the future if that change,
+    # with the same annotations as images. In the future if that changes,
     # query has to be restored to:
     # -     count(distinct i.id) as childCount)
     # - from ImageAnnotationLink ial join ial.child a join a.mapValue mv
@@ -914,7 +915,7 @@ def load_mapannotation(conn, mapann_value,
         experimenters[exp['id']] = exp
         annotations.append(d)
 
-    experimenters = experimenters.values()
+    experimenters = list(experimenters.values())
 
     return annotations, experimenters
 
